@@ -5,9 +5,9 @@ from .predicates.datetime import is_tz_aware
 from .predicates.datetime import is_tz_naive
 
 
-class TZAware(Phantom, bound=datetime.datetime, predicate=is_tz_aware):
+class TZAware(datetime.datetime, Phantom, predicate=is_tz_aware):
     ...
 
 
-class TZNaive(Phantom, bound=datetime.datetime, predicate=is_tz_naive):
+class TZNaive(datetime.datetime, Phantom, predicate=is_tz_naive):
     ...
