@@ -1,6 +1,8 @@
 from typing import Tuple
 from typing import Union
 
+import typeguard
+
 from .base import Predicate
 
 
@@ -23,3 +25,14 @@ def of_type(t: Union[type, Tuple[type, ...]]) -> Predicate[object]:
         return isinstance(a, t)
 
     return check
+
+
+def of_complex_type(t: type) -> Predicate[object]:
+    def check(a: object) -> bool:
+        try:
+            typeguard.check_type("a", a, t, globals={}, locals={})
+        except TypeError:
+            return False
+        return True
+
+    return check
